@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0502';
+our $VERSION = '0.0503';
 
 use strictures 2;
 use AI::Prolog ();
@@ -19,19 +19,7 @@ has [qw(chord_note chord mode_note mode mode_function mode_roman key_note key ke
     is => 'ro',
 );
 
-has verbose => (
-    is      => 'ro',
-    isa     => sub { croak "$_[0] is not a boolean" unless $_[0] =~ /^[01]$/ },
-    default => sub { 0 },
-);
-
-has use_scales => (
-    is      => 'ro',
-    isa     => sub { croak "$_[0] is not a boolean" unless $_[0] =~ /^[01]$/ },
-    default => sub { 0 },
-);
-
-has hash_results => (
+has [qw(verbose use_scales hash_results)] => (
     is      => 'ro',
     isa     => sub { croak "$_[0] is not a boolean" unless $_[0] =~ /^[01]$/ },
     default => sub { 0 },
@@ -52,9 +40,10 @@ has _roman_key => (
     default => sub { [qw(method mode mode_roman key key_roman)] },
 );
 
-has _modes => (
+has [qw(_modes _scales _database _prolog)] => (
     is => 'lazy',
 );
+
 sub _build__modes {
     return {
         ionian => [
@@ -123,9 +112,6 @@ sub _build__modes {
     }
 }
 
-has _scales => (
-    is => 'lazy',
-);
 sub _build__scales {
     return {
         harmonic_minor => [
@@ -189,9 +175,6 @@ sub _build__scales {
     }
 }
 
-has _database => (
-    is => 'lazy',
-);
 sub _build__database {
     my ($self) = @_;
 
@@ -206,10 +189,10 @@ sub _build__database {
         my ($mode_base) = map { lc } midi_format($base);
 
         # consider each mode or scale properties
-        for my $j (sort keys %$list) {
+        for my $item (sort keys %$list) {
             # get the notes of the base note mode or scale
-            my @notes = get_scale_notes($base, $j);
-#            warn "Basics: $base $j [@notes]\n" if $self->verbose;
+            my @notes = get_scale_notes($base, $item);
+#            warn "Basics: $base $item [@notes]\n" if $self->verbose;
 
             my @pitches; # notes suitable for the prolog database
 
@@ -220,24 +203,24 @@ sub _build__database {
                 push @pitches, map { lc } midi_format($n->format('isobase'));
             }
 
-            my $i = 0; # increment for each diatonic modes or scales
+            my $i = 0; # increment
 
             for my $pitch (@pitches) {
                 # get the properties of the given mode or scale
                 my ($chord, $function, $roman);
                 if ($self->use_scales) {
-                    $chord    = $self->_scales->{$j}[$i]{chord};
-                    $function = $self->_scales->{$j}[$i]{function};
-                    $roman    = $self->_scales->{$j}[$i]{roman};
+                    $chord    = $self->_scales->{$item}[$i]{chord};
+                    $function = $self->_scales->{$item}[$i]{function};
+                    $roman    = $self->_scales->{$item}[$i]{roman};
                 }
                 else {
-                    $chord    = $self->_modes->{$j}[$i]{chord};
-                    $function = $self->_modes->{$j}[$i]{function};
-                    $roman    = $self->_modes->{$j}[$i]{roman};
+                    $chord    = $self->_modes->{$item}[$i]{chord};
+                    $function = $self->_modes->{$item}[$i]{function};
+                    $roman    = $self->_modes->{$item}[$i]{roman};
                 }
 
                 # append to the database of facts
-                $database .= "chord_key($pitch, $chord, $mode_base, $j, $function, $roman).\n"
+                $database .= "chord_key($pitch, $chord, $mode_base, $item, $function, $roman).\n"
                     if $chord && $function && $roman;
 
                 $i++;
@@ -264,9 +247,6 @@ RULES
     return $database;
 }
 
-has _prolog => (
-    is => 'lazy',
-);
 sub _build__prolog {
     my ($self) = @_;
     return AI::Prolog->new($self->_database);
@@ -353,7 +333,7 @@ Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0502
+version 0.0503
 
 =head1 SYNOPSIS
 
@@ -439,7 +419,7 @@ chose to use "key" even though that is confusing. Argh! :|
 
 =head1 ATTRIBUTES
 
-=head2 chord_note
+=head2 chord_note, mode_note, key_note
 
 C<c>, C<db>, C<d>, C<eb>, C<e>, C<f>, C<gb>, C<g>, C<ab>, C<a>, C<bb>, or C<b>
 
@@ -449,35 +429,15 @@ C<c>, C<db>, C<d>, C<eb>, C<e>, C<f>, C<gb>, C<g>, C<ab>, C<a>, C<bb>, or C<b>
 
 C<maj>, C<min>, or C<dim>
 
-=head2 mode_note
-
-C<c>, C<db>, C<d>, C<eb>, C<e>, C<f>, C<gb>, C<g>, C<ab>, C<a>, C<bb>, or C<b>
-
-=head2 mode
+=head2 mode, key
 
 C<ionian>, C<dorian>, C<phrygian>, C<lydian>, C<mixolydian>, C<aeolian>, or C<locrian>
 
-=head2 mode_function
+=head2 mode_function, key_function
 
 C<tonic>, C<supertonic>, C<mediant>, C<subdominant>, C<dominant>, C<submediant>, C<leading_tone>, or C<subtonic>
 
-=head2 mode_roman
-
-C<r_I>, C<r_ii>, C<r_iii>, C<r_IV>, C<r_V>, C<r_vi>, or C<r_vii>
-
-=head2 key_note
-
-C<c>, C<db>, C<d>, C<eb>, C<e>, C<f>, C<gb>, C<g>, C<ab>, C<a>, C<bb>, or C<b>
-
-=head2 key
-
-C<ionian>, C<dorian>, C<phrygian>, C<lydian>, C<mixolydian>, C<aeolian>, or C<locrian>
-
-=head2 key_function
-
-C<tonic>, C<supertonic>, C<mediant>, C<subdominant>, C<dominant>, C<submediant>, C<leading_tone>, or C<subtonic>
-
-=head2 key_roman
+=head2 mode_roman, key_roman
 
 C<r_I>, C<r_ii>, C<r_iii>, C<r_IV>, C<r_V>, C<r_vi>, or C<r_vii>
 
@@ -539,16 +499,6 @@ Constructor arguments:
 
   chord_note, chord, mode_note, mode, mode_function, mode_roman, key_note, key, key_function, key_roman
 
-Here, B<chord_note> and B<chord> together are the named chord defined
-within the context of the B<mode_note> and B<mode>. The chord's
-function in the mode is the B<mode_function> and basically indicates
-the relative scale position. The B<mode_roman> argument serves as an
-indicator of both the chord quality and the position in the scale. The
-B<key_note> and B<key> are the final "destination" of the query
-transformation (often a pivot). The function of the chord in the
-"destination" is B<key_function>. As with mode_roman, B<key_roman> is
-the resulting chord quality and scale position.
-
 =head2 roman_key
 
   $results = $m->roman_key;
@@ -564,12 +514,12 @@ Constructor arguments:
 
 The F<t/01-methods.t> and F<eg/*> files in this distribution
 
-L<Moo>
-
 L<AI::Prolog>
 
 L<MIDI::Util>
 
+L<Moo>
+
 L<Music::Note>
 
 L<Music::Scales>
